@@ -17,7 +17,7 @@ sub new {
 
     my $type = $DB->type();
 
-    my $subclass = "$class::$type";
+    my $subclass = $class . '::' . $type;
     load($subclass);
 
     my $self = bless( {}, $subclass );
@@ -90,7 +90,7 @@ App::OverWatch::EventLog - EventLog base class
 
 =head1 VERSION
 
-version 0.005
+version 0.006
 
 =head1 SYNOPSIS
 
