@@ -18,7 +18,7 @@ sub new {
 
     my $type = $DB->type();
 
-    my $subclass = "$class::$type";
+    my $subclass = $class . '::' . $type;
     load($subclass);
 
     my $self = bless( {}, $subclass );
@@ -227,7 +227,7 @@ App::OverWatch::ServiceLock - ServiceLock base class
 
 =head1 VERSION
 
-version 0.005
+version 0.006
 
 =head1 SYNOPSIS
 
